/* fribidi-unicode-version.h
 * generated by gen-unicode-version (fribidi unknown)
 * from the file ReadMe.txt */

#define FRIBIDI_UNICODE_VERSION "11.0.0"
#define FRIBIDI_UNICODE_MAJOR_VERSION 11
#define FRIBIDI_UNICODE_MINOR_VERSION 0
#define FRIBIDI_UNICODE_MICRO_VERSION 0

/* End of generated fribidi-unicode-version.h */
